#define MSG_TIMEOUT "Id?tllps"
#define MSG_CAPABILITIES "Kpessg vlts sikertelen"
#define MSG_CLIENT_CLOSED_CNX "A Kliens bontotta a kapcsolatot"
#define MSG_CLIENT_READ_ERR "Kliens oldali olvassi hiba"
#define MSG_CANT_OPEN_CNX "A kapcsolat nem jtt ltre"
#define MSG_CANT_CREATE_DATA_SOCKET "Az adatcsatorna nem jtt ltre"
#define MSG_DEBUG_CLIENT_IS "A Kliens cme"
#define MSG_SYNTAX_ERROR_IP "Szintax hiba az IP cmben"
#define MSG_PORT_SUCCESSFUL "PORT parancs sikeres"
#define MSG_ONLY_IPV4V6 "Csak IPv4 s IPv6 tmogatott (1,2)"
#define MSG_ONLY_IPV4 "Csak IPv4 tmogatott (1)"
#define MSG_TIMEOUT_PARSER "Id?tllps - prblj meg kicsit gyorsabban gpelni legkzelebb"
#define MSG_LINE_TOO_LONG "A sor tl hossz"
#define MSG_LOG_OVERFLOW "A Kliens megprblta tlcsordtani a parancsvonali buffert"
#define MSG_GOODBYE "Viszlt. Te feltltttl %llu s letltttl %llu kbjtot."
#define MSG_DEBUG_COMMAND "Parancs"
#define MSG_IS_YOUR_CURRENT_LOCATION "a pillanatnyi helyzeted"
#define MSG_NOT_LOGGED_IN "Nemvagy belpve"
#define MSG_AUTH_UNIMPLEMENTED "Ez a biztonsgi sma nincsen implementlva"
#define MSG_NO_FILE_NAME "Nincs ilyen fjlnv"
#define MSG_NO_DIRECTORY_NAME "Nincs ilyen knyvtrnv"
#define MSG_NO_RESTART_POINT "Nincs jraindtsi pont"
#define MSG_ABOR_SUCCESS "Megszakts (ABOR) sikeres volt"
#define MSG_MISSING_ARG "Hinyz meghatrozs"
#define MSG_GARBAGE_FOUND "Szemt tallhat az rtk utn"
#define MSG_VALUE_TOO_LARGE "Az rtk tl nagy"
#define MSG_IDLE_TIME "resjrati id? belltva %lu msodpercre"
#define MSG_SITE_HELP "A kvetkez? SITE parancsok ismerhet?ek fel"
#define MSG_BAD_CHMOD "rvnytelen engedlyek"
#define MSG_UNKNOWN_EXTENSION "egy rvnytelen kiterjeszts"
#define MSG_XDBG_OK "XDBG parancs sikeres, debug szint %d"
#define MSG_UNKNOWN_COMMAND "Ismeretlen parancs"
#define MSG_TIMEOUT_NOOP "Id?tllps (nincs m?velet %lu msodperce)"
#define MSG_TIMEOUT_DATA "Id?tllps (nincs j adat %lu msodperce)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Mr bejelentkeztl"
#define MSG_ANY_PASSWORD "Akrmilyen jelsz megfelel"
#define MSG_ANONYMOUS_LOGGED "Anonymous felhasznl lpett be"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonymous felhasznl lpett be a virtulis FTP-n keresztl"
#define MSG_USER_OK "Felhasznl %s rendben. Krem a jelszt"
#define MSG_CANT_DO_TWICE "Ez kptelensg a jelenlegi folyamatban"
#define MSG_UNABLE_SECURE_ANON "A biztonsgos anonymous FTP kapcsolat felptse sikertelen volt"
#define MSG_BANDWIDTH_RESTRICTED "A svszlessg hasznlatod korltozva van"
#define MSG_NO_PASSWORD_NEEDED "Akrmilyen jelsz megfelel"
#define MSG_NOTRUST "Sajnlom, de nemtudok megbzni benned"
#define MSG_WHOAREYOU "Krlek mondd meg ki vagy te"
#define MSG_AUTH_FAILED "Azonosts sikertelen, sajnlom"
#define MSG_AUTH_TOOMANY "Tl sok sikertelen azonosts"
#define MSG_NO_HOMEDIR "A kezd?mappa nem elrhet?, megszakts"
#define MSG_NO_HOMEDIR2 "%s nem ltezik vagy elrhetetlen"
#define MSG_START_SLASH "Indts itt /"
#define MSG_USER_GROUP_ACCESS "A %s felhasznl csoportja"
#define MSG_FXP_SUPPORT "Ez a szerver tmogatja az FXP tvitelt"
#define MSG_RATIO "Tisztelned kell az %u:%u (UL/DL) arnyokat"
#define MSG_CHROOT_FAILED "A biztonsgos chroot() jail ltrehozsa sikertelen"
#define MSG_CURRENT_DIR_IS "Rendben. %s a jelenlegi knyvtr"
#define MSG_CURRENT_RESTRICTED_DIR_IS "Rendben. %s a jelenlegi korltozott knyvtr"
#define MSG_IS_NOW_LOGGED_IN "%s belpett"
#define MSG_CANT_CHANGE_DIR "A %s knyvtrba vlts sikertelen"
#define MSG_PATH_TOO_LONG "Az elrsi t tl hossz"
#define MSG_CANT_PASV "Nem hasznlhatsz PASV-ot IPv6 kapcsolatnl. Hasznlj EPSV-t helyette."
#define MSG_CANT_PASSIVE "A passiv md kapcsolat nem jtt ltre"
#define MSG_PORTS_BUSY "Az sszes fenntartott TCP port foglalt"
#define MSG_GETSOCKNAME_DATA "A helyi adatcsatorna azonostsa sikertelen"
#define MSG_GETPEERNAME "A helyi csatorna azonostsa sikertelen"
#define MSG_INVALID_IP "Elnzst, a megadott cm rvnytelen"
#define MSG_NO_EPSV "Krem hasznljon IPv6-szerkezetu klienst EPSV tmogatssal"
#define MSG_BAD_PORT "Hiba, nemtudok az < 1024 portokhoz kapcsoldni"
#define MSG_NO_FXP "Nemtudok kapcsolatot megnyitni megnyitni a %s -nak (csak %s -nak)"
#define MSG_FXP "FXP transfer: forrs: %s cl: %s"
#define MSG_NO_DATA_CONN "Nincs adatkapcsolat"
#define MSG_ACCEPT_FAILED "A kapcsolat nem elfogadhat"
#define MSG_ACCEPT_SUCCESS "Adatkapcsolat elfogadva"
#define MSG_CNX_PORT_FAILED "Az adatkapcsolat ltrehozsa a %d portra sikertelen"
#define MSG_CNX_PORT "Kapcsolds a  %d porthoz"
#define MSG_ANON_CANT_MKD "Hiba, anonymous felhasznlk nem hozhatnak ltre knyvtrakat"
#define MSG_ANON_CANT_RMD "Hiba, anonymous felhasznlk nem trlhetnek knyvtrakat"
#define MSG_ANON_CANT_RENAME "Anonymous felhasznlk nem mozgathatnak/nevezhetnek t knyvtrakat"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymous felhasznlk nem llthatnak engedlyeket"
#define MSG_GLOB_NO_MEMORY "Elfogyott a memria %s teljestse kzben"
#define MSG_PROBABLY_DENIED "(Ez valsznuleg ezt jelenti \"Engedly megtagadva\") "
#define MSG_GLOB_READ_ERROR "Olvassi hiba %s teljestse kzben"
#define MSG_GLOB_NO_MATCH "Nincs hasonlsg %s  ebben: %s "
#define MSG_CHMOD_FAILED "Engedlyvlts sikertelen %s"
#define MSG_CHMOD_SUCCESS "Engedlyvlts sikeres %s"
#define MSG_CHMOD_TOTAL_FAILURE "Hiba, de nemtudok engedlyt vltani"
#define MSG_ANON_CANT_DELETE "Anonymous felhasznlk nem trlhetnek"
#define MSG_ANON_CANT_OVERWRITE "Anonymous felhasznlk taln nem rhatnak fell meglvo fjlokat"
#define MSG_DELE_FAILED "Nem lehet trlni %s"
#define MSG_DELE_SUCCESS "%s trlve"
#define MSG_DELE_TOTAL_FAILURE "Egyetlen fjl sem lett trlve"
#define MSG_LOAD_TOO_HIGH \
    "A terhels %3.2f mikor csatlakoztl. A letlts le van tiltva\n" \
    "az anonymous felhasznlknak, mikor a teherls ilyen nagy. A feltltsek \n" \
    "mindg engedlyezve vannak."
#define MSG_OPEN_FAILURE "Sikertelen megnyits %s"
#define MSG_OPEN_FAILURE2 "A fjl megnyitsa sikertelen"
#define MSG_STAT_FAILURE "A fjl mrete nem tallhat"
#define MSG_STAT_FAILURE2 "A fjl ltezsnek ellenorzse sikertelen"
#define MSG_REST_TOO_LARGE_FOR_FILE "Az jraindtsi rtk %lld tl nagy a fjl mrethez %lld."
#define MSG_REST_RESET "jraindtsi rtk 0 -ra vltoztatva"
#define MSG_NOT_REGULAR_FILE "Csak hagyomnyos fjlt tud letlteni"
#define MSG_NOT_MODERATED \
    "A fjlt anonymus felhasznl tlttte fel. " \
    "a fjl letltst az adminisztrtorok mg nem hagytk jv"
#define MSG_RATIO_DENIAL \
    "Hiba, a feltltsi/letltsi arny %u:%u .\n" \
    "Feltltttl jelenleg %llu Kb s letltttl %llu Kb.\n" \
    "Krlek tlts fel valami hasznosat s utna leech-elj."
#define MSG_NO_MORE_TO_DOWNLOAD "Semmi letltenival nem maradt"
#define MSG_WINNER "A szmtgp a bartod. Bzz a szmtgpben."
#define MSG_KBYTES_LEFT "%.1f kbjt a htralvo letltendo mennyisg"
#define MSG_ABORTED "tvitel megszaktva"
#define MSG_DATA_WRITE_FAILED "rshiba az adatkapcsolatbl"
#define MSG_DATA_READ_FAILED "Olvassi hiba az adatkapcsolatbl"
#define MSG_MMAP_FAILED "A fjl memriba val bejegyzse sikertelen"
#define MSG_WRITE_FAILED "Fjlba rs kzben hiba trtnt"
#define MSG_TRANSFER_RATE_M "%.3f msodperc (itt mrve), %.2f Mbjt per msodperc"
#define MSG_TRANSFER_RATE_K "%.3f msodperc (itt mrve), %.2f Kbjt per msodperc"
#define MSG_TRANSFER_RATE_B "%.3f msodperc (itt mrve), %.2f bjt per msodperc"
#define MSG_SPACE_FREE_M "%.1f Mbjt a szabad lemezterlet"
#define MSG_SPACE_FREE_K "%f Kbjt a szabad lemezterlet"
#define MSG_DOWNLOADED "letltve"
#define MSG_REST_NOT_NUMERIC "REST numerikus paramter szksges"
#define MSG_REST_ASCII_STRICT "Reply marker must be 0 in ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "jraindts ezen a ponton %lld. De ASCII mdban vagyunk."
#define MSG_REST_SUCCESS "jraindts ezen a pontom %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Prohibited directory name"
#define MSG_SANITY_FILE_FAILURE "Tiltott fjl nv: %s"
#define MSG_MKD_FAILURE "Knyvtr ltrehozs sikertelen"
#define MSG_MKD_SUCCESS "A knyvtr sikeresen ltrejtt"
#define MSG_RMD_FAILURE "Knyvtr trlse sikertelen"
#define MSG_RMD_SUCCESS "A knyvtr sikeresen trlve"
#define MSG_TIMESTAMP_FAILURE "Az ido blyeg nem meghatrozhat"
#define MSG_MODE_ERROR "Csak ASCII s binris md tmogatott"
#define MSG_CREATE_FAILURE "Fjl ltrehozsa sikertelen"
#define MSG_ABRT_ONLY "ABRT az egyetlen jogos parancs feltlts kzben"
#define MSG_UPLOAD_PARTIAL "rszlegesen feltltve"
#define MSG_REMOVED "eltvoltva"
#define MSG_UPLOADED "feltltve"
#define MSG_GMTIME_FAILURE "Helyi ido meghatrozsa sikertelen"
#define MSG_TYPE_8BIT_FAILURE "Csak 8-bites bjtok tmogatottak, nem 10 vvel ezelott vagyunk"
#define MSG_TYPE_UNKNOWN "Ismeretlen tpus (TYPE)"
#define MSG_TYPE_SUCCESS "TYPE most"
#define MSG_STRU_FAILURE "Csak F(ile) tmogatott"
#define MSG_MODE_FAILURE "Krem hasznljon S(tream) mdot"
#define MSG_RENAME_ABORT "Elozo tnevezs megszaktva"
#define MSG_RENAME_RNFR_SUCCESS "RNFR elfogadva - fjl ltezik, ksz az j nvre"
#define MSG_FILE_DOESNT_EXIST "Hiba, a megadott fjlnv nem ltezik"
#define MSG_RENAME_ALREADY_THERE "tnevezs (RENAME) sikertelen - a clfjl mr ltezik"
#define MSG_RENAME_NORNFR "RNFR szksges RNTO elott"
#define MSG_RENAME_FAILURE "tnevezs/mozgats hiba"
#define MSG_RENAME_SUCCESS "A fjl sikeresen t lett nevezve vagy mozgatva"
#define MSG_NO_SUPERSERVER "Krem futtassa a pure-ftpd -t egy szuper szerveren bell (mint a tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nem tallom 'ftp' azonostt"
#define MSG_CONF_ERR "Konfigurcis hiba"
#define MSG_NO_VIRTUAL_FILE "A virtulis felhasznl fjlnv hinyzik"
#define MSG_ILLEGAL_THROTTLING "rvnytelen svszlessg fojt rtk"
#define MSG_ILLEGAL_TRUSTED_GID "rvnytelen megbzhat gid chroot -nak"
#define MSG_ILLEGAL_USER_LIMIT "rvnytelen felhasznl korlt"
#define MSG_ILLEGAL_FACILITY "Ismeretlen kpessg nv"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "rvnytelen LDAP konfigurcis fjl"
#define MSG_ILLEGAL_LOAD_LIMIT "rvnytelen terhelsi korlt"
#define MSG_ILLEGAL_PORTS_RANGE "rvnytelen port tartomny"
#define MSG_ILLEGAL_LS_LIMITS "rvnytelen 'ls' korltok"
#define MSG_ILLEGAL_FORCE_PASSIVE "rvnytelen eroltetett IP passzv md kapcsolathoz"
#define MSG_ILLEGAL_RATIO "rvnytelen feltltsi/letltsi rta"
#define MSG_ILLEGAL_UID_LIMIT "rvnytelen UID korlt"
#define MSG_ILLEGAL_OPTION "Ismeretlen futsi opci"
#define MSG_LDAP_MISSING_BASE "Az LDAPBaseDN hinyzik az LDAP konfigurcis fjlbl"
#define MSG_LDAP_WRONG_PARMS "Rossz LDAP paramterek"
#define MSG_NEW_CONNECTION "j kapcsolat a kvetkezo cmrol: %s"
#define MSG_WELCOME_TO "dvzlm"
#define MSG_MAX_USERS "%lu felhasznl (a maximum) mr be van lpve, sajnlom"
#define MSG_NB_USERS "Te vagy a %d a %d felhasznl kzl, aki belphet."
#define MSG_WELCOME_TIME "A Helyi Ido %02d:%02d. szerver port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Csak anonymous FTP megengedett"
#define MSG_RATIOS_EVERYONE "A RTK MINDENKIRE RVNYESEK:"
#define MSG_RATIOS_ANONYMOUS "ANONYMOUS FELHASZLK AZ UL/DL A KVETKEZO RTNAK VANNAK ALRENDELVE:"
#define MSG_RATIOS_RULE "ahhoz, hogy letlts %u Mb-ot, %u Mb nyalnksg feltltse ktelezo."
#define MSG_INFO_IDLE_M "%lu perc inaktivits utn a kapcsolat megszakad."
#define MSG_INFO_IDLE_S "%lu msodperc inaktivits utn a kapcsolat megszakad."
#define MSG_CANT_READ_FILE "Hiba, az olvass lehetetlen [%s]"
#define MSG_LS_TRUNCATED "Kimenet %u rszre csonktva"
#define MSG_LS_SUCCESS "%u az sszes megfelelo"
#define MSG_LOGOUT "Kijelentkezs."
#define MSG_AUTH_FAILED_LOG "Azonosts sikertelen [%s] felhasznlnak"
#define MSG_ILLEGAL_UMASK "rvnytelen umask"
#define MSG_STANDALONE_FAILED "Egyedlll szerver elindtsa sikertelen"
#define MSG_NO_ANONYMOUS_LOGIN "Ez egy privt rendszer - nincs anonymous bejelentkezs"
#define MSG_ANONYMOUS_ANY_PASSWORD "Brmilyen jelsz megfelel"
#define MSG_MAX_USERS_IP "Tl sok kapcsolat errol az IP-rol: (%lu) "
#define MSG_ACTIVE_DISABLED "Aktv md letiltva"
#define MSG_TRANSFER_SUCCESSFUL "A fjl sikeresen t lett tltve"
#define MSG_NO_DISK_SPACE "A Diszk tele van - krem ksobb tltsn fel"
#define MSG_OUT_OF_MEMORY "Elfogyott a memria"
#define MSG_ILLEGAL_TRUSTED_IP "rvnytelen megbzhat IP cm"
#define MSG_NO_ASCII_RESUME "ASCII folytats nem biztonsgos, krem eloszr trlje a fjlt"
#define MSG_UNKNOWN_ALTLOG "Ismeretlen naplzsi formtum"
#define MSG_ACCOUNT_DISABLED " Nemtud belpni ezzel a felhasznlnvvel: [%s]: belpsi nv letiltva"
#define MSG_SQL_WRONG_PARMS "Rossz SQL paramterek"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "rvnytelen SQL konfigurcis fjl"
#define MSG_SQL_MISSING_SERVER "Hinyzik a szerver az  SQL konfigurcis fjlbl"
#define MSG_SQL_DOWN "Az SQL szerver gyltszik nem mukdik"
#define MSG_ILLEGAL_QUOTA "rvnytelen kvta"
#define MSG_QUOTA_FILES "%llu fjl hasznlt (%d%%) - engedlyezve: %llu fjl"
#define MSG_QUOTA_SIZE "%llu Kbjt hasznlt (%d%%) - engedlyezve: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Kvta elrve: %s ments sikertelen"
#define MSG_AUTH_UNKNOWN "Ismeretlen hitelestsi mdszer"
#define MSG_PDB_BROKEN "Az indexelt puredb fjl olvassa sikertelen (vagy rgi formtum) - prblja: pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s egy alias %s -nak."
#define MSG_ALIASES_UNKNOWN "Ismeterlen alias %s."
#define MSG_ALIASES_BROKEN_FILE "Srlt alias fjlok"
#define MSG_ALIASES_LIST "A kvetkezo aliasok elrhetoek :"
#define MSG_PERUSER_MAX "Nem fogadhatok el tbb kapcsolatot, mint %lu ugyanattl a felhasznltl"
#define MSG_IPV6_OK "IPv6 kapcsolatok szintn hasznlhatak a szerveren."
#define MSG_TLS_INFO "SSL/TLS: Engedlyezve %s, %s, %d titkos bittel titkostva"
#define MSG_TLS_WEAK "SSL/TLS: Titkosts tl gyenge"
#define MSG_TLS_NEEDED "Hiba, cleartext belpsi forma nem engedlyezett.\n" \
    "Krem kapcsoldjon jra SSL/TLS biztonsgi mdot hasznlva."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
